pub enum Dimension<T> {
Undefined,
Auto,
Points(T),
Percentage(T),
}Expand description
Represents an absolute or relative dimension.
Variants
Undefined
This is the default value for a dimension and resembles
Dimension:::Points(0.0) and Dimension::Percentage(0.0).
Auto
Depending on the property that this dimension is used to, this value may
have a special meaning. Otherwise, it’s similar to
Dimension::Undefined.
Points(T)
This is a dimension expressed in absolute units, where each unit represents a single pixel.
Percentage(T)
This is a dimension expressed in relative units, where 1.0 represents 100%.