Module layout

Module layout 

Primitives to work with layout and opaque geometry.

Modules

algorithm
Implementations of the flexbox algorithm.

Structs

Layout
Computed layout of a node.
LayoutAnchor
Opaque coordinate within a reference system.
LayoutAxisY
Represents a direction independent vertical layout axis.
LayoutDistance
Distance between opaque coordinates within a reference system.
LayoutGuide
Opaque rectangle defined by coordinates within a reference system.
LayoutNode
Handle to a node within the layout tree.
LayoutTree
LayoutTree that manages the flexbox algorithm and some additional details, like the roots of the layout tree.

Enums

LayoutAxisX
Represents a potentially direction dependent horizontal layout axis.
LayoutDirection
Represents the layout direction of a language (i.e. left-to-right vs. right-to-left).
MeasureFunc
Measure function that is called to obtain the intrinsic content size of a leaf node (e.g. images or text).

Traits

Algorithm
Abstract interface of a flexbox algorithm.