Types and algorithms that implement perceptually plausible interpolation between 3D transformations.
Structs
- Decomposition3D
- This represents the decomposition of a 3D transformation matrix into three-component translation, scale and skew vectors, a four-component perspective vector and a rotation quaternion.
- Laplace
Expansion3D - Container that memoizes the results of laplace expansion that is used to compute the determinant, adjugate and (as a result) the inverse of a 3D transformation matrix.