pub struct Compositor { /* private fields */ }Expand description
Concrete implementation of a compositor that is responsible for adding and removing native views from the native view hierarchy based on the virtual representation within Polyhorn.
Implementations
Sourceimpl Compositor
impl Compositor
Sourcepub fn new(environment: Environment) -> Compositor
pub fn new(environment: Environment) -> Compositor
Returns a new compositor with the given shared layouter.