Primitives to work with layout and opaque geometry.
Modules
- algorithm
- Implementations of the flexbox algorithm.
Structs
- Layout
- Computed layout of a node.
- Layout
Anchor - Opaque coordinate within a reference system.
- Layout
AxisY - Represents a direction independent vertical layout axis.
- Layout
Distance - Distance between opaque coordinates within a reference system.
- Layout
Guide - Opaque rectangle defined by coordinates within a reference system.
- Layout
Node - Handle to a node within the layout tree.
- Layout
Tree - LayoutTree that manages the flexbox algorithm and some additional details, like the roots of the layout tree.
Enums
- Layout
AxisX - Represents a potentially direction dependent horizontal layout axis.
- Layout
Direction - Represents the layout direction of a language (i.e. left-to-right vs. right-to-left).
- Measure
Func - Measure function that is called to obtain the intrinsic content size of a leaf node (e.g. images or text).
Traits
- Algorithm
- Abstract interface of a flexbox algorithm.